@@ -60,7 +60,7 @@ class DBusTestCase(unittest.TestCase):
   <type>system</type>
   <keep_umask/>
   <listen>unix:tmpdir=/tmp</listen>
-  <standard_system_servicedirs />
+  <!-- We do not add standard_system_servicedirs (i.e. we have *no* service directory). -->
 
   <policy context="default">
     <allow send_destination="*" eavesdrop="true"/>
@@ -176,7 +176,7 @@ class DBusTestCase(unittest.TestCase):
             timeout -= 1
             time.sleep(0.1)
         if timeout <= 0:
-            assert timeout > 0, 'timed out waiting for D-Bus object %s: %s' % (path, last_exc)
+            assert timeout > 0, f'timed out waiting for D-Bus object {path}: {last_exc}'
 
     @classmethod
     def spawn_server(cls, name: str, path: str, interface: str, system_bus: bool = False, stdout: int = None):
@@ -198,6 +198,7 @@ class DBusTestCase(unittest.TestCase):
         argv.append(path)
         argv.append(interface)
 
+        # pylint: disable=consider-using-with
         daemon = subprocess.Popen(argv, stdout=stdout)
 
         # wait for daemon to start up
